
//
// PerlPoint macros used in CD production.
//
// This file is part of the YAPC::EU PerlPoint author kit.
// It declares several macros and paragraph filters. Load it via \INCLUDE.
//
// Note: macros embedding Perl code require an -activeContents option to work,
//       as well as do paragraph filters in general.
//
// (c) Jochen Stenzel, 2004-2007.
//


// declare a separator variable
$empty=

// declare a few macros
+DATE:\EMBED{lang=perl}use POSIX; strftime("%d.%m.%Y, %H:%M", localtime);\END_EMBED

+BU:\B<\U<__body__>>

+BX:\B<\X<__body__>>

+BC:\B<\C<__body__>>

+CX:\C<\X<__body__>>

+BCX:\B<\C<\X<__body__>>>

+IB:\I<\B<__body__>>

+IX:\I<\X<__body__>>

+IBX:\I<\B<\X<__body__>>>

+URL:\C<__a__>: __body__

+URLT:\C<__body__>

+MAILTO:\C<__body__>

+MAIL:\C<__body__>



+XO:\X{mode=index_only}<__body__>

// like \XO, but allow to specify multiple links at once
+XOM:\EMBED{lang=perl}
     my ($delimiter)=('__d__');
     $delimiter='|' unless $delimiter;
     join('', map {s/^\s+//; s/\s+$//; qq(\\X{mode="index_only"}<$_>)} split(quotemeta($delimiter), '__body__'));
     \END_EMBED


+CENTER:\EMBED{lang=perl}
        sprintf(
	        join("\n\n",
		     '',
                     '.',
                     '\EMBED{lang=latex}\begin{center}\%s',
                     '__body__',
                     '\EMBED{lang=latex}\end{center}\%s',
                     '.',
                    ),
                ('END_EMBED') x 2
               );
        \END_EMBED

+CENTER_ON:\EMBED{lang=html}<center>\END_EMBED\EMBED{lang=latex}\begin{center}\END_EMBED

+CENTER_OFF:\EMBED{lang=html}</center>\END_EMBED\EMBED{lang=latex}\end{center}\END_EMBED

+INDENT:\EMBED{lang=html}<ul>\END_EMBED__body__\EMBED{lang=html}</ul>\END_EMBED

+INDENT_ON:__body__

+INDENT_OFF:__body__

+SMALL:__body__

// colors
+RED:\F{color=red}<__body__>

+GREEN:\F{color=green}<__body__>

+BLUE:\F{color=blue}<__body__>

// copyright HTML
+COPYRIGHT:\EMBED{lang=html}&copy;\END_EMBED\EMBED{lang=latex}\copyright\END_EMBED

// link builder
+CPAN_MODULE:\C<__body__>



// -----------------------------------------


// These macros are "extra" definitions from the CD directories.


// NOTE: \TS is obsolete now as one can start a paragraph by a dot
//       with newer versions of the PerlPoint parser. Provided for
//       backwards compatibility.
// start a paragraph by a tag, but make it wrappable
+TS:\HIDE{_cnd_=1}<tag start>

// footnotes
+FN:\SMALL<\SEQ{type=footnotes name="__n__"}: __body__>

+FNR:\SUP<\F{size="-2"}<\REF{type=linked name="__n__"}>>

// conditional reference
+OREF:\REF{type=linked occasion=1 name="__n__"}<__body__>

// GPW
+YAPC:\XO<YAPCEurope\URL{a="http://yapc.eu/2012"}<YAPC::EU 2012>



// -----------------------------------------



// declare paragraph filters
\EMBED{lang=perl}

# center examples
sub center
 {
#  warn "\n\n\\CENTER_ON\n\n|$main::_pfilterText|\n\n\\CENTER_OFF\n\n";
#  getc;

  # just wrap what you found
  "\n\n\\CENTER_ON\n\n$main::_pfilterText\n\n\\CENTER_OFF\n\n";
 }

# highlight Perl examples
sub formatComments
 {
  $main::_pfilterText=~s/((?<!([\":\$]))#.+)$/\\GREEN<$1>/mg;
  $main::_pfilterText;
 }


# a generic function to build a highlighter object for a certain language
sub buildHighlighter
  {
   # supply a highlighter object
   return new Syntax::Highlight::Engine::Kate(
                                              language      => $_[0],
                                              substitutions => {
                                                                # '>' => '\\>',
                                                               },
                                              format_table  => {
                                                                Alert        => ['\\BLUE<', '>'],
	                                                        BaseN        => ['\F{color="#007f00"}<', '>'],
	                                                        BString      => ['\\F{color="#c9a7ff"}<', '>'],
	                                                        Char         => ['\\F{color="#ff00ff"}<', '>'],
		                                                Comment      => ['\\F{color="green"}<', '>'],
		                                                DataType     => ['\\F{color="#0000ff"}<', '>'],
		                                                DecVal       => ['\\F{color="#00007f"}<', '>'],
		                                                Error        => ['\\F{color="#ff0000"}<\\B<\\I<', '>>>'],
		                                                Float        => ['\\F{color="#00007f"}<', '>'],
		                                                Function     => ['\\F{color="#007f00"}<', '>'],
		                                                IString      => ['\\F{color="#ff0000"}<', '>'],
                                                                Keyword      => ["\\B<", '>'],
					                        Normal       => ['', ''],
					                        Operator     => ['\\F{color="#ffa500"}<', '>'],
						                Others       => ['\\F{color="#b03060"}<', '>'],
                                                                RegionMarker => ['\\F{color="#96b9ff"}\\I<', '>>'],
		                                                Reserved     => ['\\F{color="#9b30ff"}<\\B<', '>>'],
				                                String       => ['\\F{color="#ff0000"}<', '>'],
				                                Variable     => ['\\F{color="#0000ff"}<\\B<', '>>'],
				                                Warning      => ['\\F{color="#0000ff"}<\\B<\\I<', '>>>'],
				                               },
				              );
 }
 

# format Perl examples
sub formatPerl
 {
  # build a Perl highlighter (it is important to start with a new object, as used objects remember code that was processed
  # before)
  my $hl=buildHighlighter('Perl');
  # highlight text (remember, this can fail if the text has syntax errors)
  highlightText($main::_pfilterText);
 }


# declare shortcuts ...
*c=\&center;
*co=\&formatComments;
*cp=\&formatPerl;

# supply dummy PerlPoint code
'';

\END_EMBED


